@@ -1,22 +1,17 @@
 
 /* Compiler implementation of the D programming language
- * Copyright (C) 2006-2018 by The D Language Foundation, All Rights Reserved
+ * Copyright (C) 2006-2019 by The D Language Foundation, All Rights Reserved
  * written by Walter Bright
  * http://www.digitalmars.com
  * Distributed under the Boost Software License, Version 1.0.
  * http://www.boost.org/LICENSE_1_0.txt
- * https://github.com/dlang/dmd/blob/master/src/arraytypes.h
+ * https://github.com/dlang/dmd/blob/master/src/dmd/arraytypes.h
  */
 
-#ifndef DMD_ARRAYTYPES_H
-#define DMD_ARRAYTYPES_H
-
-#ifdef __DMC__
 #pragma once
-#endif /* __DMC__ */
 
-
-#include "root.h"
+#include "root/array.h"
+#include "root/bitarray.h"
 
 typedef Array<class TemplateParameter *> TemplateParameters;
 
@@ -55,8 +50,6 @@ typedef Array<class AliasDeclaration *> AliasDeclarations;
 
 typedef Array<class Module *> Modules;
 
-typedef Array<struct File *> Files;
-
 typedef Array<class CaseStatement *> CaseStatements;
 
 typedef Array<class ScopeStatement *> ScopeStatements;
@@ -70,5 +63,3 @@ typedef Array<class GotoStatement *> GotoStatements;
 typedef Array<class TemplateInstance *> TemplateInstances;
 
 typedef Array<struct Ensure> Ensures;
-
-#endif
