@@ -1,21 +1,18 @@
 
 /* Compiler implementation of the D programming language
- * Copyright (C) 1999-2018 by The D Language Foundation, All Rights Reserved
+ * Copyright (C) 1999-2019 by The D Language Foundation, All Rights Reserved
  * written by Walter Bright
  * http://www.digitalmars.com
  * Distributed under the Boost Software License, Version 1.0.
  * http://www.boost.org/LICENSE_1_0.txt
- * https://github.com/dlang/dmd/blob/master/src/mars.h
+ * https://github.com/dlang/dmd/blob/master/src/dmd/errors.h
  */
 
-#ifndef DMD_ERRORS_H
-#define DMD_ERRORS_H
-
-#ifdef __DMC__
 #pragma once
-#endif
 
-#include "mars.h"
+#include "root/dsystem.h"
+
+struct Loc;
 
 bool isConsoleColorSupported();
 
@@ -54,5 +51,3 @@ D_ATTRIBUTE_FORMAT(2, 0) void vmessage(const Loc& loc, const char *format, va_li
 // Called after printing out fatal error messages.
 D_ATTRIBUTE_NORETURN void fatal();
 D_ATTRIBUTE_NORETURN void halt();
-
-#endif /* DMD_ERRORS_H */
