@@ -1,23 +1,21 @@
 
 /* Compiler implementation of the D programming language
- * Copyright (C) 2017-2018 by The D Language Foundation, All Rights Reserved
+ * Copyright (C) 2017-2019 by The D Language Foundation, All Rights Reserved
  * written by Walter Bright
  * http://www.digitalmars.com
  * Distributed under the Boost Software License, Version 1.0.
  * http://www.boost.org/LICENSE_1_0.txt
- * https://github.com/dlang/dmd/blob/master/src/id.h
+ * https://github.com/dlang/dmd/blob/master/src/dmd/id.h
  */
 
-#ifndef DMD_ID_H
-#define DMD_ID_H
-
-#ifdef __DMC__
 #pragma once
-#endif /* __DMC__ */
+
+#if IN_LLVM
+class Identifier;
+#endif
 
 struct Id
 {
-public:
     static void initialize();
 
 #if IN_LLVM
@@ -38,6 +36,7 @@ public:
     static Identifier *crt_constructor;
     static Identifier *crt_destructor;
     static Identifier *lib;
+    static Identifier *linkerDirective;
     static Identifier *ldc;
     static Identifier *dcompute;
     static Identifier *dcPointer;
@@ -90,5 +89,3 @@ public:
     static Identifier *udaDynamicCompileEmit;
 #endif
 };
-
-#endif /* DMD_ID_H */
