@@ -13,7 +13,6 @@
 #include "dsymbol.h"
 
 struct ModuleDeclaration;
-struct Macro;
 struct Escape;
 struct FileBuffer;
 
@@ -25,6 +24,11 @@ namespace llvm {
 }
 #endif
 
+struct MacroTable
+{
+    void* internal;  // PIMPL
+};
+
 enum PKG
 {
     PKGunknown, // not yet determined whether it's a package.d or not
@@ -41,6 +45,8 @@ public:
 
     const char *kind() const;
 
+    bool equals(const RootObject *o) const;
+
     Package *isPackage() { return this; }
 
     bool isAncestorPackageOf(const Package * const pkg) const;
@@ -79,6 +85,7 @@ public:
     bool isHdrFile;     // if it is a header (.di) file
     bool isDocFile;     // if it is a documentation input file, not D source
     bool isPackageFile; // if it is a package.d
+    Package *pkg;       // if isPackageFile is true, the Package that contains this package.d
     Strings contentImportedFiles;  // array of files whose content was imported
     int needmoduleinfo;
     int selfimports;            // 0: don't know, 1: does not, 2: does
@@ -109,7 +116,7 @@ public:
     Strings *versionids;    // version identifiers
     Strings *versionidsNot;     // forward referenced version identifiers
 
-    Macro *macrotable;          // document comment macros
+    MacroTable macrotable;      // document comment macros
     Escape *escapetable;        // document comment escapes
 
     size_t nameoffset;          // offset of module name from start of ModuleInfo
