@@ -1,18 +1,13 @@
 
-/* Copyright (C) 1999-2018 by The D Language Foundation, All Rights Reserved
+/* Copyright (C) 1999-2019 by The D Language Foundation, All Rights Reserved
  * All Rights Reserved, written by Walter Bright
  * http://www.digitalmars.com
  * Distributed under the Boost Software License, Version 1.0.
- * (See accompanying file LICENSE or copy at http://www.boost.org/LICENSE_1_0.txt)
- * https://github.com/dlang/dmd/blob/master/src/root/root.h
+ * http://www.boost.org/LICENSE_1_0.txt
+ * https://github.com/dlang/dmd/blob/master/src/dmd/root/root.h
  */
 
-#ifndef ROOT_H
-#define ROOT_H
-
-#if __DMC__
 #pragma once
-#endif
 
 #if IN_LLVM
 #ifndef IS_PRINTF
@@ -33,5 +28,3 @@
 #include "outbuffer.h"
 
 #include "array.h"
-
-#endif
