@@ -51,9 +51,6 @@ typedef AsmCode code;
 struct code;
 #endif
 
-bool inferAggregate(ForeachStatement *fes, Scope *sc, Dsymbol *&sapply);
-bool inferApplyArgTypes(ForeachStatement *fes, Scope *sc, Dsymbol *&sapply);
-
 /* How a statement exits; this is returned by blockExit()
  */
 enum BE
@@ -111,7 +108,7 @@ enum
     STMTgoto,
     STMTlabel,
     STMTasm, STMTinlineAsm, STMTgccAsm,
-    STMTimport,
+    STMTimport
 };
 
 class Statement : public ASTNode
@@ -122,7 +119,7 @@ public:
 
     virtual Statement *syntaxCopy();
 
-    const char *toChars();
+    const char *toChars() const;
 
     void error(const char *format, ...);
     void warning(const char *format, ...);
@@ -484,6 +481,7 @@ public:
 
     int index;          // which case it is (since we sort this)
     VarDeclaration *lastVar;
+    void* extra;            // for use by Statement_toIR()
 
 #if IN_LLVM
     bool gototarget; // true iff this is the target of a 'goto case'
@@ -733,7 +731,7 @@ public:
     ScopeGuardStatement *os;
     VarDeclaration *lastVar;
     Statement *gotoTarget;      // interpret
-
+    void* extra;                // used by Statement_toIR()
     bool breaks;                // someone did a 'break ident'
 
     Statement *syntaxCopy();
