@@ -7,8 +7,7 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LDC_DRIVER_CL_OPTIONS_LLVM_H
-#define LDC_DRIVER_CL_OPTIONS_LLVM_H
+#pragma once
 
 #include "llvm/ADT/Optional.h"
 #include "llvm/Support/CommandLine.h"
@@ -18,17 +17,18 @@
 namespace opts {
 
 std::string getArchStr();
-#if LDC_LLVM_VER >= 309
 llvm::Optional<llvm::Reloc::Model> getRelocModel();
-#else
-llvm::Reloc::Model getRelocModel();
-#endif
 #if LDC_LLVM_VER >= 600
 llvm::Optional<llvm::CodeModel::Model> getCodeModel();
 #else
 llvm::CodeModel::Model getCodeModel();
 #endif
+#if LDC_LLVM_VER >= 800
+llvm::Optional<llvm::FramePointer::FP> framePointerUsage();
+#else
 llvm::cl::boolOrDefault disableFPElim();
+#endif
+
 bool disableRedZone();
 bool printTargetFeaturesHelp();
 
@@ -36,5 +36,3 @@ llvm::TargetOptions InitTargetOptionsFromCodeGenFlags();
 std::string getCPUStr();
 std::string getFeaturesStr();
 }
-
-#endif
