@@ -12,12 +12,9 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LDC_DRIVER_TARGET_H
-#define LDC_DRIVER_TARGET_H
+#pragma once
 
-#if LDC_LLVM_VER >= 309
 #include "llvm/ADT/Optional.h"
-#endif
 #include "llvm/Support/CodeGen.h"
 #include <string>
 #include <vector>
@@ -58,11 +55,7 @@ llvm::TargetMachine *
 createTargetMachine(std::string targetTriple, std::string arch, std::string cpu,
                     std::string featuresString, ExplicitBitness::Type bitness,
                     FloatABI::Type &floatABI,
-#if LDC_LLVM_VER >= 309
                     llvm::Optional<llvm::Reloc::Model> relocModel,
-#else
-                    llvm::Reloc::Model relocModel,
-#endif
 #if LDC_LLVM_VER >= 600
                     llvm::Optional<llvm::CodeModel::Model> codeModel,
 #else
@@ -83,5 +76,3 @@ MipsABI::Type getMipsABI();
 // Looks up a target based on an arch name and a target triple.
 const llvm::Target *lookupTarget(const std::string &arch, llvm::Triple &triple,
                                  std::string &errorMsg);
-
-#endif // LDC_DRIVER_TARGET_H
