@@ -11,13 +11,10 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LDC_DRIVER_TOOBJ_H
-#define LDC_DRIVER_TOOBJ_H
+#pragma once
 
 namespace llvm {
 class Module;
 }
 
 void writeModule(llvm::Module *m, const char *filename);
-
-#endif
