@@ -34,8 +34,11 @@ llvm::cl::opt<std::string>
 }
 
 static llvm::cl::opt<std::string>
-    gcc("gcc", llvm::cl::desc("GCC to use for assembling and linking"),
-        llvm::cl::Hidden, llvm::cl::ZeroOrMore);
+    gcc("gcc", llvm::cl::ZeroOrMore, llvm::cl::cat(opts::linkingCategory),
+        llvm::cl::value_desc("gcc|clang|..."),
+        llvm::cl::desc(
+            "C compiler to use for linking (and external assembling). Defaults "
+            "to the CC environment variable if set, otherwise to `cc`."));
 
 //////////////////////////////////////////////////////////////////////////////
 
@@ -75,12 +78,7 @@ std::string getProgram(const char *name, const llvm::cl::opt<std::string> *opt,
 ////////////////////////////////////////////////////////////////////////////////
 
 std::string getGcc() {
-#if defined(__FreeBSD__) && __FreeBSD__ >= 10
-  // Default compiler on FreeBSD 10 is clang
-  return getProgram("clang", &gcc, "CC");
-#else
-  return getProgram("gcc", &gcc, "CC");
-#endif
+  return getProgram("cc", &gcc, "CC");
 }
 
 ////////////////////////////////////////////////////////////////////////////////
