@@ -12,8 +12,7 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LDC_DRIVER_TOOL_H
-#define LDC_DRIVER_TOOL_H
+#pragma once
 
 #include <vector>
 #include <string>
@@ -51,5 +50,3 @@ bool setupMsvcEnvironment();
 }
 
 #endif
-
-#endif
