@@ -11,8 +11,7 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LDC_GEN_ABI_GENERIC_H
-#define LDC_GEN_ABI_GENERIC_H
+#pragma once
 
 #include "gen/abi.h"
 #include "gen/irstate.h"
@@ -25,12 +24,21 @@ struct LLTypeMemoryLayout {
   // Structs and static arrays are folded recursively to scalars or anonymous
   // structs.
   // Pointer types are folded to an integer type.
+  // Vector types are folded to a universal vector type.
   static LLType *fold(LLType *type) {
-    // T* => integer
+    // T* => same-sized integer
     if (type->isPointerTy()) {
       return LLIntegerType::get(gIR->context(), getTypeBitSize(type));
     }
 
+    // <N x T> => same-sized <M x i8>
+    if (type->isVectorTy()) {
+      const size_t sizeInBits = getTypeBitSize(type);
+      assert(sizeInBits % 8 == 0);
+      return llvm::VectorType::get(LLIntegerType::get(gIR->context(), 8),
+                                   sizeInBits / 8);
+    }
+
     if (LLStructType *structType = isaStruct(type)) {
       unsigned numElements = structType->getNumElements();
 
@@ -206,10 +214,12 @@ struct IndirectByvalRewrite : ABIRewrite {
 
     // the copy is treated as a local variable of the callee
     // hence add the NoAlias and NoCapture attributes
-    arg.attrs.clear()
-        .add(LLAttribute::NoAlias)
-        .add(LLAttribute::NoCapture)
-        .addAlignment(DtoAlignment(arg.type));
+    auto &attrs = arg.attrs;
+    attrs.clear();
+    attrs.addAttribute(LLAttribute::NoAlias);
+    attrs.addAttribute(LLAttribute::NoCapture);
+    if (auto alignment = DtoAlignment(arg.type))
+      attrs.addAlignmentAttr(alignment);
   }
 };
 
@@ -285,5 +295,3 @@ struct CompositeToArray32 : ABIRewrite {
     return LLArrayType::get(LLIntegerType::get(gIR->context(), 32), sz);
   }
 };
-
-#endif
