@@ -9,6 +9,7 @@
 
 #include "dmd/root/ctfloat.h"
 #include "gen/llvm.h"
+#include "llvm/Support/Error.h"
 
 using llvm::APFloat;
 
@@ -31,7 +32,11 @@ union CTFloatUnion {
 APFloat parseLiteral(const llvm::fltSemantics &semantics, const char *literal,
                      bool *isOutOfRange = nullptr) {
   APFloat ap(semantics, APFloat::uninitialized);
-  const auto r = ap.convertFromString(literal, APFloat::rmNearestTiesToEven);
+  auto r =
+#if LDC_LLVM_VER >= 1000
+      llvm::cantFail
+#endif
+      (ap.convertFromString(literal, APFloat::rmNearestTiesToEven));
   if (isOutOfRange) {
     *isOutOfRange = (r & (APFloat::opOverflow | APFloat::opUnderflow)) != 0;
   }
