@@ -124,7 +124,7 @@ RegistryStyle getModuleRegistryStyle() {
     return RegistryStyle::sectionMSVC;
   }
 
-  if (t->isMacOSX()) {
+  if (t->isOSDarwin()) {
     return RegistryStyle::sectionDarwin;
   }
 
@@ -240,7 +240,7 @@ llvm::Function *buildGetTLSAnchor() {
   const auto one = llvm::ConstantInt::get(LLType::getInt8Ty(gIR->context()), 1);
   const auto anchor =
       defineDSOGlobal("ldc.tls_anchor", one, /*isThreadLocal=*/true);
-  anchor->setAlignment(16);
+  anchor->setAlignment(LLMaybeAlign(16));
 
   const auto getAnchor = createDSOFunction(
       "ldc.get_tls_anchor", LLFunctionType::get(getVoidPtrType(), false));
@@ -604,7 +604,7 @@ void codegenModule(IRState *irs, Module *m) {
 
   // process module members
   // NOTE: m->members may grow during codegen
-  for (unsigned k = 0; k < m->members->dim; k++) {
+  for (unsigned k = 0; k < m->members->length; k++) {
     Dsymbol *dsym = (*m->members)[k];
     assert(dsym);
     Declaration_codegen(dsym);
