@@ -12,8 +12,7 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LDC_GEN_OPTIMIZER_H
-#define LDC_GEN_OPTIMIZER_H
+#pragma once
 
 // For llvm::CodeGenOpt::Level
 #include "llvm/Support/CodeGen.h"
@@ -35,7 +34,11 @@ bool willInline();
 
 bool willCrossModuleInline();
 
+#if LDC_LLVM_VER >= 800
+llvm::FramePointer::FP whichFramePointersToEmit();
+#else
 bool willEliminateFramePointer();
+#endif
 
 unsigned optLevel();
 
@@ -46,5 +49,3 @@ llvm::CodeGenOpt::Level codeGenOptLevel();
 void verifyModule(llvm::Module *m);
 
 void outputOptimizationSettings(llvm::raw_ostream &hash_os);
-
-#endif
