@@ -49,7 +49,7 @@ struct DComputeSemanticAnalyser : public StoppableVisitor {
       return false;
 
     Objects *tiargs = inst->tiargs;
-    size_t i = 0, len = tiargs->dim;
+    size_t i = 0, len = tiargs->length;
     IF_LOG Logger::println("checking against: %s (%p) (dyncast=%d)",
                            f->toPrettyChars(), (void *)f, f->dyncast());
     LOG_SCOPE
@@ -112,7 +112,7 @@ struct DComputeSemanticAnalyser : public StoppableVisitor {
   // Nogc enforcement.
   // No need to check AssocArrayLiteral because AA's are banned anyway
   void visit(ArrayLiteralExp *e) override {
-    if (e->type->ty != Tarray || !e->elements || !e->elements->dim)
+    if (e->type->ty != Tarray || !e->elements || !e->elements->length)
       return;
     e->error("array literal in `@compute` code not allowed");
     stop = true;
@@ -172,20 +172,38 @@ struct DComputeSemanticAnalyser : public StoppableVisitor {
     stop = true;
   }
   void visit(SwitchStatement *e) override {
-    if (e->condition->op == TOKcall &&
-        static_cast<CallExp *>(e->condition)->f->ident == Id::__switch) {
-      e->error("cannot `switch` on strings in `@compute` code");
-      stop = true;
+    if (auto ce = e->condition->isCallExp()) {
+      if (ce->f->ident == Id::__switch) {
+        e->error("cannot `switch` on strings in `@compute` code");
+        stop = true;
+      }
     }
   }
 
   void visit(IfStatement *stmt) override {
+    // Don't descend into ctfe only code
+    if (stmt->condition->op == TOKvar) {
+      auto ve = (VarExp *)stmt->condition;
+      if (ve->var->ident == Id::ctfe) {
+        if (stmt->elsebody)
+          visit(stmt->elsebody);
+        stop = true;
+      }
+    } else if (stmt->condition->op == TOKnot) {
+      auto ne = (NotExp *) stmt->condition;
+      if (ne->e1->op == TOKvar) {
+        auto ve = (VarExp * )ne->e1;
+        if (ve->var->ident == Id::ctfe) {
+          visit(stmt->ifbody);
+        stop = true;
+        }
+      }
+    }
     // Code inside an if(__dcompute_reflect(0,0)) { ...} is explicitly
     // for the host and is therefore allowed to call non @compute functions.
     // Thus, the if-statement body's code should not be checked for
     // @compute semantics and the recursive visitor should stop here.
-    if (stmt->condition->op == TOKcall) {
-      auto ce = (CallExp *)stmt->condition;
+    if (auto ce = stmt->condition->isCallExp()) {
       if (ce->f && ce->f->ident == Id::dcReflect) {
         auto arg1 = (DComputeTarget::ID)(*ce->arguments)[0]->toInteger();
         if (arg1 == DComputeTarget::Host)
@@ -256,7 +274,7 @@ struct DComputeSemanticAnalyser : public StoppableVisitor {
 void dcomputeSemanticAnalysis(Module *m) {
   DComputeSemanticAnalyser v;
   RecursiveWalker r(&v);
-  for (unsigned k = 0; k < m->members->dim; k++) {
+  for (unsigned k = 0; k < m->members->length; k++) {
     Dsymbol *dsym = (*m->members)[k];
     assert(dsym);
     IF_LOG Logger::println("dcomputeSema: %s: %s", m->toPrettyChars(),
