@@ -327,7 +327,7 @@ void DtoMemSet(LLValue *dst, LLValue *val, LLValue *nbytes, unsigned align) {
 
   dst = DtoBitCast(dst, VoidPtrTy);
 
-  gIR->ir->CreateMemSet(dst, val, nbytes, align, false /*isVolatile*/);
+  gIR->ir->CreateMemSet(dst, val, nbytes, LLMaybeAlign(align), false /*isVolatile*/);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -350,7 +350,8 @@ void DtoMemCpy(LLValue *dst, LLValue *src, LLValue *nbytes, unsigned align) {
   src = DtoBitCast(src, VoidPtrTy);
 
 #if LDC_LLVM_VER >= 700
-  gIR->ir->CreateMemCpy(dst, align, src, align, nbytes, false /*isVolatile*/);
+  auto A = LLMaybeAlign(align);
+  gIR->ir->CreateMemCpy(dst, A, src, A, nbytes, false /*isVolatile*/);
 #else
   gIR->ir->CreateMemCpy(dst, src, nbytes, align, false /*isVolatile*/);
 #endif
@@ -460,7 +461,7 @@ LLValue *DtoLoad(LLValue *src, const char *name) {
 // the type.
 LLValue *DtoAlignedLoad(LLValue *src, const char *name) {
   llvm::LoadInst *ld = gIR->ir->CreateLoad(src, name);
-  ld->setAlignment(getABITypeAlign(ld->getType()));
+  ld->setAlignment(LLMaybeAlign(getABITypeAlign(ld->getType())));
   return ld;
 }
 
@@ -497,7 +498,7 @@ void DtoAlignedStore(LLValue *src, LLValue *dst) {
   assert(src->getType() != llvm::Type::getInt1Ty(gIR->context()) &&
          "Should store bools as i8 instead of i1.");
   llvm::StoreInst *st = gIR->ir->CreateStore(src, dst);
-  st->setAlignment(getABITypeAlign(src->getType()));
+  st->setAlignment(LLMaybeAlign(getABITypeAlign(src->getType())));
 }
 
 ////////////////////////////////////////////////////////////////////////////////
