@@ -316,7 +316,7 @@ public:
         global.params.targetTriple->getArch() == llvm::Triple::x86_64;
     const unsigned expectedFields = 11 + (isX86_64 ? 2 : 0);
     const unsigned actualFields =
-        structTypeInfoDecl->fields.dim -
+        structTypeInfoDecl->fields.length -
         1; // union of xdtor/xdtorti counts as 2 overlapping fields
     if (actualFields != expectedFields) {
       error(Loc(), "Unexpected number of `object.TypeInfo_Struct` fields; "
@@ -510,7 +510,7 @@ public:
     assert(decl->tinfo->ty == Ttuple);
     TypeTuple *tu = static_cast<TypeTuple *>(decl->tinfo);
 
-    size_t dim = tu->arguments->dim;
+    size_t dim = tu->arguments->length;
     std::vector<LLConstant *> arrInits;
     arrInits.reserve(dim);
 
