@@ -7,7 +7,7 @@ echo ======== Testing Double Precision ========
 $DMD -m${MODEL} ${EXTRA_FILES}/paranoia.d -version=Double -of${OUTPUT_BASE}_2${EXE}
 ${OUTPUT_BASE}_2${EXE}
 
-if [ "${OS}" == "win64" -o "${OS}" == "win32" ]; then
+if [ "${OS}" == "windows" ]; then
     echo ======== Testing Extended Precision ========
     $DMD -m${MODEL} ${EXTRA_FILES}/paranoia.d -version=Extended ../../../dmd/root/longdouble.d -of${OUTPUT_BASE}_3${EXE}
     ${OUTPUT_BASE}_3${EXE}
@@ -30,5 +30,5 @@ $DMD -m${MODEL} -c -o- ${EXTRA_FILES}/paranoia.d -version=Double -version=CTFE
 echo ======== Testing CTFE Extended Precision ========
 $DMD -m${MODEL} -c -o- ${EXTRA_FILES}/paranoia.d -version=Extended -version=CTFE
 
-rm ${OUTPUT_BASE}_[1-4]${EXE}
-rm ${OUTPUT_BASE}_[1-4]${OBJ}
+rm_retry ${OUTPUT_BASE}_[1-4]${EXE}
+rm_retry ${OUTPUT_BASE}_[1-4]${OBJ}
